==> open_swarm-0.1.1744936380.tar.gz: open_swarm-0.1.1744936380/tests/blueprints/test_divine_code.py <==
import pytest
from unittest.mock import patch, AsyncMock, MagicMock

# Assuming BlueprintBase and other necessary components are importable
# from blueprints.divine_code.blueprint_divine_code import DivineOpsBlueprint
# from agents import Agent, Runner, RunResult, MCPServer

@pytest.fixture
def divine_ops_blueprint_instance():
    """Fixture to create a mocked instance of DivineOpsBlueprint."""
    with patch('blueprints.divine_code.blueprint_divine_code.BlueprintBase._load_configuration', return_value={'llm': {'default': {'provider': 'openai', 'model': 'gpt-mock'}}, 'mcpServers': {}}):
         with patch('blueprints.divine_code.blueprint_divine_code.BlueprintBase._get_model_instance') as mock_get_model:
             mock_model_instance = MagicMock()
             mock_get_model.return_value = mock_model_instance
             from blueprints.divine_code.blueprint_divine_code import DivineOpsBlueprint
             # Provide mock MCP server list during instantiation if needed, though create_starting_agent handles filtering
             instance = DivineOpsBlueprint(debug=True)
    return instance

# --- Test Cases ---

@pytest.mark.skip(reason="Blueprint tests not yet implemented")
def test_divineops_agent_creation(divine_ops_blueprint_instance):
    """Test if Zeus and the pantheon agents are created correctly."""
    # Arrange
    blueprint = divine_ops_blueprint_instance
    # Mock MCP servers (can be simple mocks if only names are checked)
    mock_mcp_list = [
        MagicMock(spec=MCPServer, name="memory"),
        MagicMock(spec=MCPServer, name="filesystem"),
        MagicMock(spec=MCPServer, name="mcp-shell"),
        MagicMock(spec=MCPServer, name="sqlite"),
        MagicMock(spec=MCPServer, name="sequential-thinking"),
        MagicMock(spec=MCPServer, name="brave-search"),
    ]

    # Act
    starting_agent = blueprint.create_starting_agent(mcp_servers=mock_mcp_list)

    # Assert
    assert starting_agent is not None
    assert starting_agent.name == "Zeus"
    tool_names = {t.name for t in starting_agent.tools}
    expected_tools = {"Odin", "Hermes", "Hephaestus", "Hecate", "Thoth", "Mnemosyne", "Chronos"}
    assert tool_names == expected_tools
    # Could add checks here that worker agents received the correct filtered MCP list
    # This would require accessing the created agents, possibly via the tools on Zeus.

@pytest.mark.skip(reason="Blueprint interaction tests not yet implemented")
@pytest.mark.asyncio
async def test_divineops_delegation_to_odin(divine_ops_blueprint_instance):
    """Test if Zeus correctly delegates an architecture task to Odin."""
    # Needs Runner mocking to trace agent calls and tool usage (Zeus -> Odin tool)
    assert False

@pytest.mark.skip(reason="Blueprint interaction tests not yet implemented")
@pytest.mark.asyncio
async def test_divineops_full_flow_example(divine_ops_blueprint_instance):
    """Test a hypothetical multi-step flow (e.g., Design -> Breakdown -> Implement)."""
    # Needs complex Runner mocking simulating multiple turns and tool calls.
    assert False

@pytest.mark.skip(reason="Blueprint CLI tests not yet implemented")
def test_divineops_cli_execution():
    """Test running the blueprint via CLI."""
    # Needs subprocess testing or direct call to main with mocked Runner/Agents/MCPs.
    assert False

==> open_swarm-0.1.1744952955.tar.gz: open_swarm-0.1.1744952955/tests/blueprints/test_divine_code.py <==
import pytest
from unittest.mock import patch, AsyncMock, MagicMock

# Assuming BlueprintBase and other necessary components are importable
# from blueprints.divine_code.blueprint_divine_code import DivineOpsBlueprint
# from agents import Agent, Runner, RunResult, MCPServer

@pytest.fixture
def divine_ops_blueprint_instance():
    """Fixture to create a mocked instance of DivineOpsBlueprint."""
    # Patch the correct import path for BlueprintBase
    with patch('swarm.core.blueprint_base.BlueprintBase._load_and_process_config', return_value={'llm': {'default': {'provider': 'openai', 'model': 'gpt-mock'}}, 'mcpServers': {}}):
        with patch('swarm.core.blueprint_base.BlueprintBase._get_model_instance') as mock_get_model:
            mock_model_instance = MagicMock()
            mock_get_model.return_value = mock_model_instance
            from swarm.blueprints.divine_code.blueprint_divine_code import DivineOpsBlueprint
            instance = DivineOpsBlueprint(blueprint_id="test_divineops", debug=True)
            # Manually set config and mcp_server_configs to avoid RuntimeError
            instance._config = {'llm': {'default': {'provider': 'openai', 'model': 'gpt-mock'}}, 'mcpServers': {}}
            instance.mcp_server_configs = {}
            return instance

# --- Test Cases ---

def test_divineops_agent_creation(divine_ops_blueprint_instance):
    """Test if Zeus and the pantheon agents are created correctly."""
    # Arrange
    blueprint = divine_ops_blueprint_instance
    # Mock MCP servers (can be simple mocks if only names are checked)
    m1 = MagicMock()
    m1.name = "memory"
    m2 = MagicMock()
    m2.name = "filesystem"
    m3 = MagicMock()
    m3.name = "mcp-shell"
    m4 = MagicMock()
    m4.name = "sqlite"
    m5 = MagicMock()
    m5.name = "sequential-thinking"
    m6 = MagicMock()
    m6.name = "brave-search"
    mock_mcp_list = [m1, m2, m3, m4, m5, m6]

    # Act
    starting_agent = blueprint.create_starting_agent(mcp_servers=mock_mcp_list)

    # Assert
    assert starting_agent is not None
    assert starting_agent.name == "Zeus"
    tool_names = {t.name for t in starting_agent.tools}
    expected_tools = {"Odin", "Hermes", "Hephaestus", "Hecate", "Thoth", "Mnemosyne", "Chronos"}
    assert tool_names == expected_tools
    # Could add checks here that worker agents received the correct filtered MCP list
    # This would require accessing the created agents, possibly via the tools on Zeus.

@pytest.mark.skip(reason="Blueprint interaction tests not yet implemented")
@pytest.mark.asyncio
async def test_divineops_delegation_to_odin(divine_ops_blueprint_instance):
    """Test if Zeus correctly delegates an architecture task to Odin."""
    # Needs Runner mocking to trace agent calls and tool usage (Zeus -> Odin tool)
    assert False

@pytest.mark.skip(reason="Blueprint interaction tests not yet implemented")
@pytest.mark.asyncio
async def test_divineops_full_flow_example(divine_ops_blueprint_instance):
    """Test a hypothetical multi-step flow (e.g., Design -> Breakdown -> Implement)."""
    # Needs complex Runner mocking simulating multiple turns and tool calls.
    assert False

@pytest.mark.skip(reason="Blueprint CLI tests not yet implemented")
def test_divineops_cli_execution():
    """Test running the blueprint via CLI."""
    # Needs subprocess testing or direct call to main with mocked Runner/Agents/MCPs.
    assert False
